\name{chadd}
\alias{chadd}
\title{Add elements to a chplot}
\description{
  \code{chadd} is a function that adds any further elements to a plot
 produced with the function \code{chplot}.
}
\usage{
chadd(param,pos,add.fun,...)
}
\arguments{
\item{param}{the parameters specifying the plotting regions. As obtained from
\code{chplot}.
}
\item{pos}{
the plotting region to which an element is to be added: \code{1} for the main plot,
\code{2} for top left (marginal distribution plot of the x-variable),
\code{3} for top right (the legend),
\code{4} for bottom right (marginal distribution plot of the y-variable).
}
\item{add.fun}{the function to be applied.
}
\item{...}{
 optional parameters to \code{add.fun}.}
}

\examples{
data(hdr)
# hdr dataset
param<-chplot(hdr,log="x")
# box around the legend region
chadd(param,3,box,"figure")
# tickmark for overall mean in marginal distribution plots
chadd(param,2,lines,c(mean(hdr$income),mean(hdr$income)),c(0,.05))
chadd(param,4,lines,c(0,.025),c(mean(hdr$age),mean(hdr$age)))
}
\seealso{\code{chplot}.}

\keyword{aplot}

\eof
\name{chplot}
\alias{chplot}


\title{Augmented Convex Hull Plot}
\description{
  Plots 2D convex hulls or bivariate density contours, one for each
  group of data. Descriptive statistics are plotted as error bars or
  confidence ellipses within convex hulls. Marginal distributions
  as well as a special legend are added by default. Additionally, area
  of convex hull per point can be displayed.
}
\usage{
chplot(x,y,groups,chull=TRUE,clevel=0.95,band.power=.2,
mar.den=FALSE,descriptives="mean.sd",dlevel=0.68,bw=FALSE,ratio=.75,
plot.points=FALSE,log="",xlab,ylab,legend,...)
}
\arguments{
\item{x}{a matrix of three columns, representing the x and y
coordinates and the grouping variable, respectively. Alternatively, \code{x}
can have just two columns (the second is regarded as y) or just be a
vector of x coordinates. If \code{x} is a data.frame, the names of the
variables are used for the axes and legend title.
}
\item{y}{
the y coordinates of points in the plot, optional if \code{x} is an appropriate structure.
}
\item{groups}{group codes of points in the plot, optional if \code{x} is an appropriate structure.
}
\item{chull}{
 logical; if \code{TRUE} (default), convex hulls are plotted,
 otherwise density contours are drawn.
}
\item{clevel}{
the confidence level for the density plot if
\code{chull=FALSE} (default is 0.95).
}
\item{band.power}{
applies if \code{chull=FALSE}; bandwidth for bivariate density estimation
is calculated as \code{(group size)^(-band.power)} for each group
(default is 0.2).
}
\item{mar.den}{ logical; defines the nature of marginal distribution
plots. If \code{FALSE} (default), relative frequency polygons are
plotted, otherwise density plots are drawn.
}
\item{descriptives}{
the option to be used for depicting descriptive statistics. The default value
is \code{mean.sd}, which produces a cross with the lines intersecting at
the mean of \code{x} and \code{y} for each group and depicting the 68-percent tolerance interval
(i.e., stretching one standard deviation in each direction) with default \code{dlevel} setting.
Option \code{mean.se} does the same with standard errors of the means,
while \code{median} makes the lines one quartile long in each direction and
cross at the median. Option \code{ellipse} plots confidence ellipses.
}
\item{dlevel}{
the tolerance/confidence level applied if \code{descriptives=mean.sd} or
\code{mean.sd}.
}
\item{bw}{
logical; if \code{TRUE}, the plot is produced in black-and-white. The
default is \code{FALSE}, which plots in colour.
}
\item{ratio}{
the ratio of the main plot to the whole figure region. The default
value is 0.75. If equal to 1, the marginal distributions are not plotted.
If the ratio is less or equal to 0.75, the default legend position is
outside the main plot (i.e., in the top right corner), otherwise it is
within the main plot (i.e., to be selected by the user with mouse).
}
\item{plot.points}{
logical; if \code{true}, the points are drawn in addition to the convex
hulls or density contours.
}
\item{log}{
 the character strings \code{"x"}, \code{"y"} or \code{"xy"} makes a
 specific (or both) axes logarithmic; the default, which does nothing, is \code{""}.
}
\item{xlab}{
a title for the x axis in the main plot; the default is the name of
the x variable.
}
\item{ylab}{
a title for the y axis in the main plot; the default is the name of
the y variable.
}
\item{legend}{
object of class \code{legend.control} specifying various parameters for the legend.
 Default is \code{legend.control(...)}. 
}
\item{...}{other arguments will be passed to \code{legend.control}}
}

\details{
The relative frequency polygons chosen with \code{mar.den=FALSE}
connect the points in the middle of the intervals and the starting and
ending interval with zero frequency in each group. All the
frequencies are rescaled in order to make the plots immediately
comparable (the same is true for the density curves).

The default density contour might not fit into the plot - this can be
avoided by decreasing the \code{clevel}. In such cases the
area does not provide a sensible measure.
}

\value{
a list with components:
\item{usrc}{the limits of the central plotting region.}
\item{usru}{the limits of the top left plotting region.}
\item{usrr}{the limits of the bottom right plotting region.}
\item{ratio}{the ratio used.}
\item{is.xlog}{logical, denoting whether either \code{log="x"}
 or  \code{log="xy"} was used.}
\item{is.ylog}{logical, denoting whether either \code{log="y"}
 or  \code{log="xy"} was used.}
}

\examples{
# the hdr dataset
data(hdr)
chplot(hdr,log="x")
# the iris dataset
data(iris)
chplot(iris[,c(1,2,5)],bw=TRUE,legend.control(cex=.6))
}

\seealso{\code{chadd}, \code{chull}, \code{bkde2D}, \code{legend.control}. }

\keyword{hplot}

\eof
\name{hdr}
\alias{hdr}
\docType{data}
\title{Deceased in Slovenia in 1998}
\description{
  Personal income tax payed (in SIT), age (in years) and gender for deceased in Slovenia in 1998.
}
\usage{data(hdr)}
\format{
\code{hdr} is a list with 9051 cases (rows) and 3 variables (columns) named \code{income}, \code{age} and \code{gender}.
}
\source{Statistical Office of the Republic of Slovenia.}
\references{
Javornik, J., and Korosec, V. Eds. (2003) \emph{Human development report Slovenia 2002/2003: Human development and health}.
Ljubljana: Institute of Macroecomic Analysis and Development.
}

\keyword{datasets}

\eof
\name{legend.control}
\alias{legend.control}


\title{Options for legend in chplot}
\description{Checks and packages the legend options \code{chplot}
}
\usage{
legend.control(include=TRUE,area.in,pos,cex,bty,title)
}
\arguments{
\item{include}{
logical; if \code{TRUE} (default), a legend is created.
}
\item{pos}{
forces the position of the legend. The available options are \code{in} and \code{out}; the default depends on \code{ratio} value.
If \code{in} is chosen, the legend is positioned by the user with mouse; \code{out} places the legend in the top right corner of
the plotting area.
}
\item{area.in}{
logical; if \code{TRUE}, the area per point is calculated for each group and included in
the legend. The default is \code{TRUE} if \code{chull=TRUE} and \code{FALSE} otherwise.
}
\item{cex}{
 A numerical value giving the amount by which text in the legend should be scaled relative to the default.
}
\item{bty}{
the type of box to be drawn around the legend. See \code{par}.
}
\item{title}{
the title of the legend; the default is the name of the grouping
variable.
}
}

\value{
A list with the same elements as the input.
}

\seealso{\code{chplot}.}

\keyword{hplot}

\eof
